@@ -44,10 +44,10 @@ __global__  void CoherentTst(int *ptr, int PeakClk) {
   // Incrementing the value by 1
   int64_t GpuFrq = int64_t(PeakClk) * 1000;
   int64_t StrtTck = clock64();
-  atomicAdd(ptr, 1);
+  atomicAdd_system(ptr, 1);
   // The following while loop checks the value in ptr for around 3-4 seconds
   while ((clock64() - StrtTck) <= (3 * GpuFrq)) {
-    if (atomicCAS(ptr, 3, 4) == 3) break;
+    if (atomicCAS_system(ptr, 3, 4) == 3) break;
   }
 }
 
@@ -55,11 +55,11 @@ __global__  void CoherentTst_gfx11(int *ptr, int PeakClk) {
 #if HT_AMD
   // Incrementing the value by 1
   int64_t GpuFrq = int64_t(PeakClk) * 1000;
-  int64_t StrtTck = wall_clock64();
-  atomicAdd(ptr, 1);
+  int64_t StrtTck = clock_function();
+  atomicAdd_system(ptr, 1);
   // The following while loop checks the value in ptr for around 3-4 seconds
-  while ((wall_clock64() - StrtTck) <= (3 * GpuFrq)) {
-    if (atomicCAS(ptr, 3, 4) == 3) break;
+  while ((clock_function() - StrtTck) <= (3 * GpuFrq)) {
+    if (atomicCAS_system(ptr, 3, 4) == 3) break;
   }
 #endif
 }
