@@ -252,110 +252,6 @@ TEST_CASE("Unit_hipGetDeviceAttribute_CheckAttrValues") {
                                        props.texturePitchAlignment));
 }
 
-/*
- * Validate the hipDeviceAttributeFineGrainSupport property in AMD.
- */
-#ifdef __linux__
-#if HT_AMD
-#define COMMAND_LEN 256
-#define BUFFER_LEN 512
-
-static bool isRocmPathSet() {
-  FILE *fpipe;
-  char const *command = "echo $ROCM_PATH";
-  fpipe = popen(command, "r");
-
-  if (fpipe == nullptr) {
-    printf("Unable to create command\n");
-    return false;
-  }
-  char command_op[BUFFER_LEN];
-  if (fgets(command_op, BUFFER_LEN, fpipe)) {
-    size_t len = strlen(command_op);
-    if (len > 1) {  // This is because fgets always adds newline character
-      pclose(fpipe);
-      return true;
-    }
-  }
-  pclose(fpipe);
-  return false;
-}
-
-/**
- * Test Description
- * ------------------------
- *  - Validate fine grain support attribute against
- *    known values for different AMD architectures
- * Test source
- * ------------------------
- *  - unit/device/hipGetDeviceAttribute.cc
- * Test requirements
- * ------------------------
- *  - Platform specific (AMD)
- *  - HIP_VERSION >= 5.2
- */
-TEST_CASE("Unit_hipGetDeviceAttribute_CheckFineGrainSupport") {
-  int deviceId;
-  int deviceCount = 0;
-  FILE *fpipe;
-  char command[COMMAND_LEN] = "";
-  const char *rocmpath = nullptr;
-  if (isRocmPathSet()) {
-    // For STG2 testing where /opt/rocm path is not present
-    rocmpath = "$ROCM_PATH/bin/rocminfo";
-  } else {
-    // Check if the rocminfo tool exists
-    rocmpath = "/opt/rocm/bin/rocminfo";
-  }
-  snprintf(command, COMMAND_LEN, "%s", rocmpath);
-  strncat(command, " | grep -i \"Segment:\\|Uuid:\"", COMMAND_LEN);
-  // Execute the rocminfo command and extract the segment info
-  fpipe = popen(command, "r");
-  if (fpipe == nullptr) {
-    printf("Unable to create command file\n");
-    return;
-  }
-  HIP_CHECK(hipGetDeviceCount(&deviceCount));
-  assert(deviceCount > 0);
-  int *fine_grained_val = new int[deviceCount];
-  assert(fine_grained_val != nullptr);
-  bool *gpuFound = new bool[deviceCount];
-  assert(gpuFound != nullptr);
-  for (int i = 0; i < deviceCount; i++) {
-    gpuFound[i] = false;
-    fine_grained_val[i] = 0;  // Initialize to 0
-  }
-  char command_op[BUFFER_LEN];
-  int count = -1;
-  // Extract each segment flags
-  while (fgets(command_op, BUFFER_LEN, fpipe)) {
-    std::string rocminfo_line(command_op);
-    if ((std::string::npos != rocminfo_line.find("GPU-")) &&
-        (std::string::npos != rocminfo_line.find("Uuid:"))) {
-      count++;
-      gpuFound[count] = true;
-    } else if (gpuFound[count] &&
-    (std::string::npos != rocminfo_line.find("FLAGS: FINE GRAINED"))) {
-      fine_grained_val[count] = 1;
-    }
-  }
-  for (int dev = 0; dev < deviceCount; dev++) {
-    HIP_CHECK(hipSetDevice(dev));
-    HIP_CHECK(hipGetDevice(&deviceId));
-    hipDeviceProp_t props;
-    HIP_CHECK(hipGetDeviceProperties(&props, deviceId));
-    int value = 0;
-    HIP_CHECK(hipDeviceGetAttribute(&value,
-              hipDeviceAttributeFineGrainSupport, deviceId));
-    REQUIRE(value == fine_grained_val[dev]);
-  }
-  // Validate hipDeviceAttributeFineGrainSupport
-  delete[] fine_grained_val;
-  delete[] gpuFound;
-}
-#endif
-#endif
-
 /**
  * Test Description
  * ------------------------
@@ -644,3 +540,8 @@ TEST_CASE("Unit_hipGetDeviceAttribute_hipDevAttrHostRegisterSupported") {
     return;
   }
 }
+
+/**
+* End doxygen group DeviceTest.
+* @}
+*/
