@@ -488,12 +488,16 @@ bool validateStreamPrioritiesWithEvents() {
   OP(low, high)
   #undef OP
 
-  // free host & device memory
+  // free host & device memory & events
   #define OP(x) \
     free(src_h_##x); \
     free(dst_h_##x); \
     HIP_CHECK(hipFree(src_d_##x)); \
-    HIP_CHECK(hipFree(dst_d_##x));
+    HIP_CHECK(hipFree(dst_d_##x)); \
+    if (enable_priority_##x) { \
+      HIP_CHECK(hipEventDestroy(event_start_##x)); \
+      HIP_CHECK(hipEventDestroy(event_end_##x)); \
+    }
   OP(low)
   OP(normal)
   OP(high)
@@ -801,6 +805,46 @@ void TestForMultipleStreamWithPriority(void) {
       REQUIRE(memcmp(dst_h_high[i], src_h_high[i], size) == 0);
     }
   }
+
+
+  //Free memory
+  for (int i = 0; i < LOW_PRIORITY_STREAMCOUNT; ++i) {
+    if (enable_priority_low) {
+      HIP_CHECK(hipStreamDestroy(stream_low[i]));
+      HIP_CHECK(hipEventDestroy(event_start_low[i]));
+      HIP_CHECK(hipEventDestroy(event_end_low[i]));
+      free(src_h_low[i]);
+      free(dst_h_low[i]);
+      HIP_CHECK(hipFree(src_d_low[i]));
+      HIP_CHECK(hipFree(dst_d_low[i]));
+    }
+  }
+
+  for (int i = 0; i < NORMAL_PRIORITY_STREAMCOUNT; ++i) {
+    if (enable_priority_normal) {
+      HIP_CHECK(hipStreamDestroy(stream_normal[i]));
+      HIP_CHECK(hipEventDestroy(event_start_normal[i]));
+      HIP_CHECK(hipEventDestroy(event_end_normal[i]));
+      free(src_h_normal[i]);
+      free(dst_h_normal[i]);
+      HIP_CHECK(hipFree(src_d_normal[i]));
+      HIP_CHECK(hipFree(dst_d_normal[i]));
+    }
+  }
+
+  for (int i = 0; i < HIGH_PRIORITY_STREAMCOUNT; ++i) {
+    if (enable_priority_high) {
+      HIP_CHECK(hipStreamDestroy(stream_high[i]));
+      HIP_CHECK(hipEventDestroy(event_start_high[i]));
+      HIP_CHECK(hipEventDestroy(event_end_high[i]));
+      free(src_h_high[i]);
+      free(dst_h_high[i]);
+      HIP_CHECK(hipFree(src_d_high[i]));
+      HIP_CHECK(hipFree(dst_d_high[i]));
+    }
+  }
+
+
 }
 }  // namespace hipStreamCreateWithPriorityTest
 
@@ -1011,3 +1055,8 @@ TEST_CASE("Unit_hipStreamCreateWithPriority_ValidateWithEvents") {
 TEST_CASE("Unit_hipStreamCreateWithPriority_TestMultipleStreamWithPriority") {
   hipStreamCreateWithPriorityTest::TestForMultipleStreamWithPriority<int>();
 }
+
+/**
+* End doxygen group StreamTest.
+* @}
+*/
